OiRA

# Hairdressers

By filling in the list of questions, you have completed a risk assessment. This assessment is used to draw up an action plan. The progress of this action plan must be discussed annually and a small report must be written on the progress. Certain subjects might have been completed and perhaps new subjects need to be added.

Your answers and report were automatically saved and may be found back or deleted at any time via the preparation step.

Bedrijfsnaam | Not provided
Postal address | Not provided
Visitor's address | Not provided
Email address | Not provided
Telephone number | Not provided
Activity | Not provided
Name submitter | Not provided
Function submitter | Not provided
Department | Not provided
Location | Not provided
Submitted on | 20 Ιουλίου 2010
Email address | Not provided
Number of employees | Not provided
Absentee percentage | Not provided
Number of accidents last year | Not provided
Number of incapacitated workers last year | Not provided
Arbo export | Not provided

## Table of contents

## 3 Preventing work related injuries"

### 3.3 Electrical safety"

#### ⚠3.3.2 Electrical equipment is not connected to an earth leakage circuit breaker.

This is a medium priority risk .

An Earth Leakage Circuit Breaker (ELCB) is a safety device used in electrical installations with high earth impedance to prevent electric shock.

##### Measure 1

General approach (to eliminate or reduce the risk): | -

#### ⚠3.3.3 Protection devices are present and not function correctly.

This is a high priority risk .

Electrical circuits need protection devices at various points to isolate faults that can occur.

##### Measure 1

General approach (to eliminate or reduce the risk): | -

#### ⚠3.3.4 Leads are not properly insulated, they are damaged, and they are lying on the ground.

This is a low priority risk .

All electrical cables are somewhat flexible. Where applications require a cable to be moved repeatedly, such as for portable equipment, more flexible cables called "cords" or "flex" are used. Flexible cords contain fine stranded conductors, not solid core conductors, and have insulation and sheaths to withstand the forces of repeated flexing and abrasion.

##### Measure 1

General approach (to eliminate or reduce the risk): | -

*) This risk is not present in your organisation, but since the sector organisation considers this one of the top 5 most critical risks it must be included in this report.

- This report was based on the survey 'version 1.0' of revision date 13 Αυγούστου 2010.
- The works council has not approved this report.